=======
GeniePy
=======


Gene-Disease relationship trend detection application


Description
===========

A longer description of your project goes here...


Installation
============

**Install with pip**

::

    pip install geniepy



**Install from source code**

::

    git clone https://github.com/derekkinzo/genie.git

    cd genie/geniepy

    python setup.py install

**Generate Python Package**

::

    python setup.py sdist bdist_wheel

    twine upload dist/*

**Python Package Development**

::

    python setup.py develop

    python setup.py test

    python setup.py docs